# PTWordFinder
"What specific words would you like to read?"
Counting words in "Pan Tadeusz" poem

## Python version
Python 3.10.6

## Why
It was started as a project to exercise python language. The code helped to find specific words in a selected file. It became command line tool that help find any word within any file. The files can be selected by command line

## how to use
Usage: PTWordFinder.py WORDS_INPUT SEARCHED_FILE
Try 'PTWordFinder.py --help' for help

you can installl this cmd tool from pip:

```
    pip install PTWordFinder
```

example:
Python3 PanTadeuszWordFinder.py words.txt text-novel.txt

## Features
- [x] poem lines counter
- [x] a specific word counter
- [x] tracking the script execution time
